select_door: Select the contestant's first pick of doors

Description Usage Arguments Details Value Examples

View source: R/monty-hall-problem.R View source: R/monty-hall-problem.R

Description

the contestants first pick of a door, numbered 1-3. randomly assigns a number 1-3 as the contestant's first pick

Usage

1

Arguments

no

arguments are used in select_door

Details

all three doors are still closed and available to the contestant

Value

the function returns a randomly generated number (1-3) indicating the door which the contestant first "picked"

1
 the function will place the number into a.pick

Examples

1
2
3
4
select_door will return one of the following:
     [1] 1
     [1] 2
     [1] 3

AmyTrumpower/montyhall documentation built on Dec. 17, 2021, 8:47 a.m.