Description Usage Arguments Details Value
View source: R/monty-hall-problem.R View source: R/monty-hall-problem.R View source: R/monty-hall-problem.R
1 2 | plays the full version of the games a number of times
initially set at 100 games
|
1 2 | plays the full version of the games a number of times
initially set at 100 games
|
1 2 3 | play_n_games(n = 100)
play_n_games(n = 100)
|
the |
function can run for any integer of gameplays. n=100 initially sets the game at 100 plays |
1 2 3 4 5 6 |
1 2 3 4 5 6 |
1 2 |
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.