Description Usage Arguments Details Value Examples
View source: R/monty-hall-problem.R View source: R/monty-hall-problem.R
the contestants first pick of a door, numbered 1-3. randomly assigns a number 1-3 as the contestant's first pick
1 |
no |
arguments are used in select_door |
all three doors are still closed and available to the contestant
the function returns a randomly generated number (1-3) indicating the door which the contestant first "picked"
1 | the function will place the number into a.pick
|
1 2 3 4 | select_door will return one of the following:
[1] 1
[1] 2
[1] 3
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.